==> beast-0.6.1.tar.gz: beast-0.6.1/beast-gtk/gxk/gxk.h <==
/* GXK - Gtk+ Extension Kit
 * Copyright (C) 2002 Tim Janik
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GXK_H__
#define __GXK_H__

#include <sfi/glib-extra.h>
#include <gtk/gtk.h>

#include <gxk/glewidgets.h>
#include <gxk/gxkaction.h>
#include <gxk/gxkauxwidgets.h>
#include <gxk/gxkcanvas.h>
#include <gxk/gxkcellrendererpopup.h>
#include <gxk/gxkdialog.h>
#include <gxk/gxkgadget.h>
#include <gxk/gxkgadgetfactory.h>
#include <gxk/gxkglobals.h>
#include <gxk/gxkled.h>
#include <gxk/gxklistwrapper.h>
#include <gxk/gxkmenubutton.h>
#include <gxk/gxkparam.h>
#include <gxk/gxklogadjustment.h>
#include <gxk/gxkpolygon.h>
#include <gxk/gxkracktable.h>
#include <gxk/gxkrackitem.h>
#include <gxk/gxkscrollcanvas.h>
#include <gxk/gxksimplelabel.h>
#include <gxk/gxkstatusbar.h>
#include <gxk/gxkstock.h>
#include <gxk/gxktexttools.h>
#include <gxk/gxkutils.h>

#endif /* __GXK_H__ */

==> beast-0.6.2.tar.gz: beast-0.6.2/beast-gtk/gxk/gxk.h <==
/* GXK - Gtk+ Extension Kit
 * Copyright (C) 2002 Tim Janik
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GXK_H__
#define __GXK_H__

#include <sfi/glib-extra.h>
#include <gtk/gtk.h>

#include <gxk/glewidgets.h>
#include <gxk/gxkaction.h>
#include <gxk/gxkauxwidgets.h>
#include <gxk/gxkcanvas.h>
#include <gxk/gxkcellrendererpopup.h>
#include <gxk/gxkdialog.h>
#include <gxk/gxkradget.h>
#include <gxk/gxkradgetfactory.h>
#include <gxk/gxkglobals.h>
#include <gxk/gxkled.h>
#include <gxk/gxklistwrapper.h>
#include <gxk/gxkmenubutton.h>
#include <gxk/gxkparam.h>
#include <gxk/gxklogadjustment.h>
#include <gxk/gxkpolygon.h>
#include <gxk/gxkracktable.h>
#include <gxk/gxkrackitem.h>
#include <gxk/gxkscrollcanvas.h>
#include <gxk/gxksimplelabel.h>
#include <gxk/gxkstatusbar.h>
#include <gxk/gxkstock.h>
#include <gxk/gxktexttools.h>
#include <gxk/gxkutils.h>

#endif /* __GXK_H__ */
